@@ -19,15 +19,19 @@ def attr_callback(ctx: MethodContext, typ: str) -> Type:
     """Callback to determine type for a ``.attr`` call on a ``Maybe``.
     """
     (attr, ), = ctx.arg_types
-    if not isinstance(attr, Instance
-                      ) or not isinstance(attr.last_known_value, LiteralType):
+    attr_maybe_value: t.Optional[Type] = attr
+    if isinstance(attr, Instance):
+        attr_maybe_value = attr.last_known_value
+
+    if not isinstance(attr_maybe_value, LiteralType):
         ctx.api.fail(
             'The attr to Maybe.attr should be a literal',
             ctx.context,
         )
         return ctx.default_return_type
 
-    attr_value = attr.last_known_value.value
+    attr_value = attr_maybe_value.value
+
     if not isinstance(attr_value, str):  # pragma: no cover
         return ctx.default_return_type
 
