@@ -18,8 +18,10 @@ from . import (
     oauth_token,
     permission,
     plagiarism,
+    role,
     site_settings,
     snippet,
+    sso_provider,
     submission,
     task_result,
     tenant,
