@@ -31,6 +31,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     )
     from ..models.create_course_data import CreateCourseData
     from ..models.create_group_set_course_data import CreateGroupSetCourseData
+    from ..models.create_role_course_data import CreateRoleCourseData
     from ..models.create_snippet_course_data import CreateSnippetCourseData
     from ..models.email_users_course_data import EmailUsersCourseData
     from ..models.extended_course import ExtendedCourse
@@ -42,6 +43,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.import_into_course_data import ImportIntoCourseData
     from ..models.job import Job
     from ..models.patch_course_data import PatchCourseData
+    from ..models.patch_role_course_data import PatchRoleCourseData
     from ..models.patch_snippet_course_data import PatchSnippetCourseData
     from ..models.put_enroll_link_course_data import PutEnrollLinkCourseData
     from ..models.put_price_course_data import PutPriceCourseData
@@ -167,6 +169,112 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_course_roles(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        with_roles: "bool" = False,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Union[t.Sequence[CourseRoleAsJSONWithPerms], t.Sequence[CourseRole]]":
+        """Get a list of all course roles in a given course.
+
+        :param course_id: The id of the course to get the roles for.
+        :param with_roles: Should a permission map be added to each role.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An array of all course roles for the given course.
+        """
+
+        url = "/api/v1/courses/{courseId}/roles/".format(courseId=course_id)
+        params: t.Dict[str, t.Any] = {
+            **(extra_parameters or {}),
+            "with_roles": utils.to_dict(with_roles),
+        }
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_role import CourseRole
+            from ..models.course_role_as_json_with_perms import (
+                CourseRoleAsJSONWithPerms,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.make_union(
+                    rqa.List(
+                        parsers.ParserFor.make(CourseRoleAsJSONWithPerms)
+                    ),
+                    rqa.List(parsers.ParserFor.make(CourseRole)),
+                )
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def create_role(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "CreateRoleCourseData"],
+        *,
+        course_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Add a new `CourseRole` to the given `Course`.
+
+        :param json_body: The body of the request. See
+            :class:`.CreateRoleCourseData` for information about the possible
+            fields. You can provide this data as a
+            :class:`.CreateRoleCourseData` or as a dictionary.
+        :param course_id: The id of the course
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An empty response with return code 204.
+        """
+
+        url = "/api/v1/courses/{courseId}/roles/".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.post(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def create_snippet(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateSnippetCourseData"],
@@ -428,6 +536,54 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_all_enroll_links(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[CourseRegistrationLink]":
+        """Get the registration links for the given course.
+
+        :param course_id: The course id for which to get the registration
+            links.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An array of registration links.
+        """
+
+        url = "/api/v1/courses/{courseId}/registration_links/".format(
+            courseId=course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_registration_link import CourseRegistrationLink
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(CourseRegistrationLink))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def put_enroll_link(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PutEnrollLinkCourseData"],
@@ -676,6 +832,108 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_registration_link(
+        self,
+        *,
+        course_id: "int",
+        link_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "ExtendedCourseRegistrationLink":
+        """Get a registration link.
+
+        This route can be used without logging in, i.e. you don't have to be
+        enrolled in the course to use this route. This route will not work for
+        expired registration links.
+
+        :param course_id: The id of the course to which the registration link
+            is connected.
+        :param link_id: The id of the registration link.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The specified registration link.
+        """
+
+        url = "/api/v1/courses/{courseId}/registration_links/{linkId}".format(
+            courseId=course_id, linkId=link_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.extended_course_registration_link import (
+                ExtendedCourseRegistrationLink,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ExtendedCourseRegistrationLink)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def delete_enroll_link(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        link_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Delete the given registration link.
+
+        :param course_id: The id of the course to which the registration link
+            is connected.
+        :param link_id: The id of the registration link.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Nothing.
+        """
+
+        url = "/api/v1/courses/{courseId}/registration_links/{linkId}".format(
+            courseId=course_id, linkId=link_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.delete(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def delete_role(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
@@ -721,46 +979,93 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def get_course_roles(
+    def patch_role(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "PatchRoleCourseData"],
         *,
         course_id: "int",
+        role_id: "int",
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
-    ) -> "t.Union[t.Sequence[CourseRoleAsJSONWithPerms], t.Sequence[CourseRole]]":
-        """Get a list of all course roles in a given course.
+    ) -> "None":
+        """Update the `Permission` of a given `CourseRole` in the given
+        `Course`.
 
-        :param course_id: The id of the course to get the roles for.
+        :param json_body: The body of the request. See
+            :class:`.PatchRoleCourseData` for information about the possible
+            fields. You can provide this data as a
+            :class:`.PatchRoleCourseData` or as a dictionary.
+        :param course_id: The id of the course.
+        :param role_id: The id of the course role.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: An array of all course roles for the given course.
+        :returns: An empty response with return code 204.
         """
 
-        url = "/api/v1/courses/{courseId}/roles/".format(courseId=course_id)
+        url = "/api/v1/courses/{courseId}/roles/{roleId}".format(
+            courseId=course_id, roleId=role_id
+        )
         params = extra_parameters or {}
 
         with self.__client as client:
-            resp = client.http.get(url=url, params=params)
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
         utils.log_warnings(resp)
 
-        if utils.response_code_matches(resp.status_code, 200):
+        if utils.response_code_matches(resp.status_code, 204):
             # fmt: off
-            from ..models.course_role import CourseRole
-            from ..models.course_role_as_json_with_perms import (
-                CourseRoleAsJSONWithPerms,
-            )
-
             # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.make_union(
-                    rqa.List(
-                        parsers.ParserFor.make(CourseRoleAsJSONWithPerms)
-                    ),
-                    rqa.List(parsers.ParserFor.make(CourseRole)),
-                )
-            ).try_parse(resp)
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def delete_user(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        user_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Delete a user from a course.
+
+        This does not delete the user's submissions within the course.
+
+        :param course_id: The id of the course to remove the user from.
+        :param user_id: The id of the user to remove from the course.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Nothing.
+        """
+
+        url = "/api/v1/courses/{courseId}/users/{userId}".format(
+            courseId=course_id, userId=user_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.delete(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
 
         from ..models.any_error import AnyError
 
@@ -840,7 +1145,7 @@ class CourseService(t.Generic[_ClientT]):
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
-    ) -> t.Union["UserCourse", "None"]:
+    ) -> "UserCourse":
         """Set the `CourseRole` of a user in the given course.
 
         :param json_body: The body of the request. See
@@ -852,10 +1157,8 @@ class CourseService(t.Generic[_ClientT]):
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: If the user\_id parameter is set in the request the response
-                  will be empty with return code 204. Otherwise the response
-                  will contain the JSON serialized user and course role with
-                  return code 201
+        :returns: The response will contain the JSON serialized user and course
+                  role.
         """
 
         url = "/api/v1/courses/{courseId}/users/".format(courseId=course_id)
@@ -875,10 +1178,6 @@ class CourseService(t.Generic[_ClientT]):
             return parsers.JsonResponseParser(
                 parsers.ParserFor.make(UserCourse)
             ).try_parse(resp)
-        if utils.response_code_matches(resp.status_code, 204):
-            # fmt: off
-            # fmt: on
-            return parsers.ConstantlyParser(None).try_parse(resp)
 
         from ..models.any_error import AnyError
 
@@ -1139,62 +1438,6 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def get_registration_link(
-        self,
-        *,
-        course_id: "int",
-        link_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "ExtendedCourseRegistrationLink":
-        """Get a registration link.
-
-        This route can be used without logging in, i.e. you don't have to be
-        enrolled in the course to use this route. This route will not work for
-        expired registration links.
-
-        :param course_id: The id of the course to which the registration link
-            is connected.
-        :param link_id: The id of the registration link.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The specified registration link.
-        """
-
-        url = "/api/v1/courses/{courseId}/registration_links/{linkId}".format(
-            courseId=course_id, linkId=link_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.get(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.extended_course_registration_link import (
-                ExtendedCourseRegistrationLink,
-            )
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.ParserFor.make(ExtendedCourseRegistrationLink)
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
     def get_submissions_by_user(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
