@@ -52,10 +52,14 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from codegrade._api.plagiarism import (
         PlagiarismService as _PlagiarismService,
     )
+    from codegrade._api.role import RoleService as _RoleService
     from codegrade._api.site_settings import (
         SiteSettingsService as _SiteSettingsService,
     )
     from codegrade._api.snippet import SnippetService as _SnippetService
+    from codegrade._api.sso_provider import (
+        SSOProviderService as _SSOProviderService,
+    )
     from codegrade._api.submission import (
         SubmissionService as _SubmissionService,
     )
@@ -93,8 +97,10 @@ class _BaseClient:
         "__oauth_token",
         "__permission",
         "__plagiarism",
+        "__role",
         "__site_settings",
         "__snippet",
+        "__sso_provider",
         "__submission",
         "__task_result",
         "__tenant",
@@ -144,10 +150,14 @@ class _BaseClient:
         self.__plagiarism: t.Optional[
             "_PlagiarismService[_BaseClientT]"
         ] = None
+        self.__role: t.Optional["_RoleService[_BaseClientT]"] = None
         self.__site_settings: t.Optional[
             "_SiteSettingsService[_BaseClientT]"
         ] = None
         self.__snippet: t.Optional["_SnippetService[_BaseClientT]"] = None
+        self.__sso_provider: t.Optional[
+            "_SSOProviderService[_BaseClientT]"
+        ] = None
         self.__submission: t.Optional[
             "_SubmissionService[_BaseClientT]"
         ] = None
@@ -374,6 +384,15 @@ class _BaseClient:
             self.__plagiarism = m.PlagiarismService(self)
         return self.__plagiarism
 
+    @property
+    def role(self: _BaseClientT) -> "_RoleService[_BaseClientT]":
+        """Get a :class:`.RoleService` to do requests concerning Role."""
+        if self.__role is None:
+            import codegrade._api.role as m
+
+            self.__role = m.RoleService(self)
+        return self.__role
+
     @property
     def site_settings(
         self: _BaseClientT,
@@ -396,6 +415,19 @@ class _BaseClient:
             self.__snippet = m.SnippetService(self)
         return self.__snippet
 
+    @property
+    def sso_provider(
+        self: _BaseClientT,
+    ) -> "_SSOProviderService[_BaseClientT]":
+        """Get a :class:`.SSOProviderService` to do requests concerning
+        SSOProvider.
+        """
+        if self.__sso_provider is None:
+            import codegrade._api.sso_provider as m
+
+            self.__sso_provider = m.SSOProviderService(self)
+        return self.__sso_provider
+
     @property
     def submission(self: _BaseClientT) -> "_SubmissionService[_BaseClientT]":
         """Get a :class:`.SubmissionService` to do requests concerning
