@@ -4,6 +4,7 @@ SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 
 from ._base_price import _BasePrice
+from ._saml_ui_logo_info import _SamlUiLogoInfo
 from ._submission_rubric_item_data_parser import (
     _SubmissionRubricItemDataParser,
 )
@@ -186,7 +187,10 @@ from .create_proxy_submission_data import CreateProxySubmissionData
 from .create_repository_git_provider_data import (
     CreateRepositoryGitProviderData,
 )
+from .create_role_course_data import CreateRoleCourseData
 from .create_snippet_course_data import CreateSnippetCourseData
+from .create_snippet_data import CreateSnippetData
+from .create_sso_provider_data import CreateSSOProviderData
 from .create_tenant_data import CreateTenantData
 from .currency import Currency
 from .custom_output_as_json import CustomOutputAsJSON
@@ -346,6 +350,7 @@ from .min_password_score_setting import MinPasswordScoreSetting
 from .mirror_file_result import MirrorFileResult
 from .missing_cookie_error import MissingCookieError
 from .missing_file import MissingFile
+from .no_permissions import NoPermissions
 from .non_deleted_comment_reply import NonDeletedCommentReply
 from .non_finalized_lti1p1_provider import NonFinalizedLTI1p1Provider
 from .non_finalized_lti1p3_provider import NonFinalizedLTI1p3Provider
@@ -380,6 +385,10 @@ from .patch_notification_data import PatchNotificationData
 from .patch_notification_setting_user_setting_data import (
     PatchNotificationSettingUserSettingData,
 )
+from .patch_provider_lti_data import PatchProviderLTIData
+from .patch_role_course_data import PatchRoleCourseData
+from .patch_role_data import PatchRoleData
+from .patch_role_tenant_data import PatchRoleTenantData
 from .patch_rubric_category_type_assignment_data import (
     PatchRubricCategoryTypeAssignmentData,
 )
@@ -389,6 +398,7 @@ from .patch_rubric_result_submission_data import (
 from .patch_settings_tenant_data import PatchSettingsTenantData
 from .patch_site_settings_data import PatchSiteSettingsData
 from .patch_snippet_course_data import PatchSnippetCourseData
+from .patch_snippet_data import PatchSnippetData
 from .patch_submission_data import PatchSubmissionData
 from .patch_submit_types_assignment_data import PatchSubmitTypesAssignmentData
 from .patch_tenant_data import PatchTenantData
@@ -430,6 +440,7 @@ from .result_data_get_task_result_get_all import ResultDataGetTaskResultGetAll
 from .result_data_post_login_link_login import ResultDataPostLoginLinkLogin
 from .result_data_post_user_login import ResultDataPostUserLogin
 from .result_data_post_user_register import ResultDataPostUserRegister
+from .role_as_json_with_perms import RoleAsJSONWithPerms
 from .root_file_trees_json import RootFileTreesJSON
 from .rubric_description_type import RubricDescriptionType
 from .rubric_item import RubricItem
@@ -445,6 +456,8 @@ from .run_program_data import RunProgramData
 from .run_program_extra import RunProgramExtra
 from .run_program_input_as_json import RunProgramInputAsJSON
 from .run_program_log import RunProgramLog
+from .saml2_provider_json import Saml2ProviderJSON
+from .saml_ui_info import SamlUiInfo
 from .send_registration_email_setting import SendRegistrationEmailSetting
 from .server_time_correction_enabled_setting import (
     ServerTimeCorrectionEnabledSetting,
@@ -471,7 +484,9 @@ from .tax_behavior import TaxBehavior
 from .tenant import Tenant
 from .tenant_course_statistics import TenantCourseStatistics
 from .tenant_of_tenant_price import TenantOfTenantPrice
+from .tenant_permissions import TenantPermissions
 from .tenant_price import TenantPrice
+from .tenant_role_as_json_with_perms import TenantRoleAsJSONWithPerms
 from .tenant_statistics import TenantStatistics
 from .transaction import Transaction
 from .transaction_state import TransactionState
