@@ -68,6 +68,9 @@ class GlobalPermMap:
     #: Users with this permission can see the pricing coupons generated for the
     #: courses they are part of.
     can_see_coupons: "bool"
+    #: Users with this permission can get a list of all AutoTest results that
+    #: have not yet started running.
+    can_view_not_started_autotest_results: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -236,6 +239,14 @@ class GlobalPermMap:
                     " generated for the courses they are part of."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_view_not_started_autotest_results",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can get a list of all AutoTest"
+                    " results that have not yet started running."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -270,6 +281,9 @@ class GlobalPermMap:
             "can_see_all_transactions": to_dict(self.can_see_all_transactions),
             "can_edit_coupons": to_dict(self.can_edit_coupons),
             "can_see_coupons": to_dict(self.can_see_coupons),
+            "can_view_not_started_autotest_results": to_dict(
+                self.can_view_not_started_autotest_results
+            ),
         }
         return res
 
@@ -301,6 +315,7 @@ class GlobalPermMap:
             can_see_all_transactions=parsed.can_see_all_transactions,
             can_edit_coupons=parsed.can_edit_coupons,
             can_see_coupons=parsed.can_see_coupons,
+            can_view_not_started_autotest_results=parsed.can_view_not_started_autotest_results,
         )
         res.raw_data = d
         return res
