@@ -29,3 +29,6 @@ class GlobalPermission(str, Enum):
     can_see_all_transactions = "can_see_all_transactions"
     can_edit_coupons = "can_edit_coupons"
     can_see_coupons = "can_see_coupons"
+    can_view_not_started_autotest_results = (
+        "can_view_not_started_autotest_results"
+    )
