@@ -88,6 +88,7 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
             "created_at": to_dict(self.created_at),
             "intended_use": to_dict(self.intended_use),
             "tenant_id": to_dict(self.tenant_id),
+            "label": to_dict(self.label),
         }
         return res
 
@@ -110,6 +111,7 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
             created_at=parsed.created_at,
             intended_use=parsed.intended_use,
             tenant_id=parsed.tenant_id,
+            label=parsed.label,
         )
         res.raw_data = d
         return res
